FunctionResolver
================

.. currentmodule:: class_resolver

.. autoclass:: FunctionResolver
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~FunctionResolver.options

   .. rubric:: Methods Summary

   .. autosummary::

      ~FunctionResolver.docdata
      ~FunctionResolver.extract_name
      ~FunctionResolver.extract_synonyms
      ~FunctionResolver.from_entrypoint
      ~FunctionResolver.get_option
      ~FunctionResolver.lookup
      ~FunctionResolver.make
      ~FunctionResolver.make_safe
      ~FunctionResolver.normalize
      ~FunctionResolver.optuna_lookup
      ~FunctionResolver.register
      ~FunctionResolver.register_entrypoint

   .. rubric:: Attributes Documentation

   .. autoattribute:: options

   .. rubric:: Methods Documentation

   .. automethod:: docdata
   .. automethod:: extract_name
   .. automethod:: extract_synonyms
   .. automethod:: from_entrypoint
   .. automethod:: get_option
   .. automethod:: lookup
   .. automethod:: make
   .. automethod:: make_safe
   .. automethod:: normalize
   .. automethod:: optuna_lookup
   .. automethod:: register
   .. automethod:: register_entrypoint
